// Function to initialize the token if it doesn't exist
async function initializeToken() {
    return new Promise((resolve) => {
        chrome.storage.local.get(['browserToken'], (result) => {
            if (!result.browserToken) {
                const randomString = crypto.randomUUID(); // Generate a random UUID
                const token = md5(randomString); // Generate MD5 of the random string

                chrome.storage.local.set({ browserToken: token }, () => {
                    console.log("Token initialized:", token);

                    // Update the display
                    const displayToken = md5(token); // MD5 of the token for display
                    updateTokenDisplay(displayToken);
                    resolve(token);
                });
            } else {
                const displayToken = md5(result.browserToken); // MD5 of the token for display
                updateTokenDisplay(displayToken);
                resolve(result.browserToken); // Token already exists
            }
        });
    });
}

// Function to reset the token
async function resetToken() {
    const randomString = crypto.randomUUID();
    const token = md5(randomString);

    chrome.storage.local.set({ browserToken: token }, () => {
        console.log("Token reset:", token);

        // Update the display
        const displayToken = md5(token); // MD5 of the token for display
        updateTokenDisplay(displayToken);
    });
}

// Function to update the token display
function updateTokenDisplay(token) {
    const tokenDisplayElement = document.getElementById("tokenDisplay");
    tokenDisplayElement.innerText = `Browser Token:\n ${token}`;
    tokenDisplayElement.setAttribute("title", "Click and copy this token.");
}

// Display the token when the popup is loaded
window.addEventListener("DOMContentLoaded", async () => {
    const token = await initializeToken(); // Ensure the token exists
    const displayToken = md5(token); // MD5 of the token for display
    updateTokenDisplay(displayToken);
});

// Wait for the DOM to fully load
window.addEventListener("DOMContentLoaded", () => {
    const resetButton = document.getElementById("resetToken");

    if (resetButton) {
        // Add an event listener to the reset button
        resetButton.addEventListener("click", resetToken);
    } else {
        console.error("Reset button not found in the DOM.");
    }
});


